pub enum BBQError {
InternalLatchingFault,
UseBeforeInitLatchingFault,
Bbq(BBQError),
}Expand description
The defmt-brtt BBQueue error type
Variants
InternalLatchingFault
An internal latching fault has occured. No more logs will be returned.
This indicates a coding error in defmt-bbq. Please open an issue.
UseBeforeInitLatchingFault
The user attempted to log before initializing the defmt-bbq structure.
This is a latching fault, and not recoverable, but is not an indicator of
a failure in the library. If you see this error, please ensure that you
call defmt-bbq::init() before making any defmt logging statements.
Bbq(BBQError)
This indicates some potentially recoverable bbqerror (including no data currently available).