DefmtConsumer

Struct DefmtConsumer 

pub struct DefmtConsumer { /* private fields */ }
The consumer interface of defmt-log.

This type is a wrapper around the bbqueue::Consumer type, and returns defmt-brtt’s Error type instead of bbqueue’s bbqueue::Error type.

Implementations

Source

impl DefmtConsumer

pub fn read<'a>(&'a mut self) -> Result<GrantR<'a, BUF_SIZE>, Error>

Obtains a contiguous slice of committed bytes. This slice may not contain ALL available bytes, if the writer has wrapped around. The remaining bytes will be available after all readable bytes are released.

pub fn split_read(&mut self) -> Result<SplitGrantR<'static, BUF_SIZE>, Error>

Obtains two disjoint slices, which are each contiguous of committed bytes. Combined these contain all previously commited data at the time of read

Source

impl DefmtConsumer

pub async fn wait_for_log<'a>(&'a mut self) -> GrantR<'a, BUF_SIZE>