pub fn init() -> Result<DefmtConsumer, Error>Expand description
Initialize the BBQueue based global defmt sink. MUST be called before
the first defmt log, or it will latch a fault.
On the first call to this function, the Consumer end of the logging queue will be returned. On any subsequent call, an error will be returned.
For more information on the Consumer interface, see the Consumer docs in the bbqueue
crate documentation.