pub struct DefmtConsumer { /* private fields */ }Expand description
The consumer interface of defmt-log.
This type is a wrapper around the bbqueue::Consumer type, and returns defmt-brtt’s Error type instead of bbqueue’s bbqueue::Error type.
Implementations
Sourceimpl DefmtConsumer
impl DefmtConsumer
Sourcepub fn read<'a>(&'a mut self) -> Result<GrantR<'a, BUF_SIZE>, Error>
pub fn read<'a>(&'a mut self) -> Result<GrantR<'a, BUF_SIZE>, Error>
Obtains a contiguous slice of committed bytes. This slice may not contain ALL available bytes, if the writer has wrapped around. The remaining bytes will be available after all readable bytes are released.
Sourcepub fn split_read(&mut self) -> Result<SplitGrantR<'static, BUF_SIZE>, Error>
pub fn split_read(&mut self) -> Result<SplitGrantR<'static, BUF_SIZE>, Error>
Obtains two disjoint slices, which are each contiguous of committed bytes. Combined these contain all previously commited data at the time of read
Sourceimpl DefmtConsumer
impl DefmtConsumer
pub async fn wait_for_log<'a>(&'a mut self) -> GrantR<'a, BUF_SIZE>